@@ -147,7 +147,10 @@ class TobiiGlassesController():
 						jdata = json.loads(data.decode('utf-8'))
 						logging.debug("From: " + address[0] + " " + str(data))
 						logging.debug("Tobii Pro Glasses found with address: [%s]" % address[0])
-						return (jdata, address[0])
+						addr = address[0]
+						if sys.version_info.major == 3 and sys.version_info.minor >= 8:
+							addr = address[0] + '%' + if_name
+						return (jdata, addr)
 					except:
 						logging.debug("No device found on interface %s" % if_name)
 
@@ -160,7 +163,10 @@ class TobiiGlassesController():
 	def __get_request__(self, api_action):
 		url = self.base_url + api_action
 		res = urlopen(url).read()
-		data = json.loads(res.decode('utf-8'))
+		try:
+			data = json.loads(res.decode('utf-8'))
+		except json.JSONDecodeError:
+			data = None
 		return data
 
 	def __grab_data__(self, socket):
@@ -184,7 +190,7 @@ class TobiiGlassesController():
 		sock.settimeout(5.0)
 		try:
 			if iptype == socket.AF_INET6:
-				sock.setsockopt(socket.SOL_SOCKET, 25, self.iface_name+'\0')
+				sock.setsockopt(socket.SOL_SOCKET, 25, 1)
 		except socket.error as e:
 			if e.errno == 1:
 				logging.warning("Binding to a network interface is permitted only for root users.")
